@@ -1115,7 +1115,7 @@ int wcmDevOpen(WacomDevicePtr priv)
  * Any de-facto defined axis index left unused is initialized with default
  * attributes.
  */
-static int wcmInitAxes(WacomDevicePtr priv)
+static int wcmInitAxes(WacomDevicePtr priv, Bool use_smooth_panscrolling)
 {
 	WacomCommonPtr common = priv->common;
 	int min, max, res;
@@ -1220,7 +1220,7 @@ static int wcmInitAxes(WacomDevicePtr priv)
 		wcmInitAxis(priv, WACOM_AXIS_RING2, min, max, res);
 	}
 
-	if (IsPen(priv)) {
+	if (use_smooth_panscrolling && IsPen(priv)) {
 		/* seventh valuator: scroll_x */
 		wcmInitAxis(priv, WACOM_AXIS_SCROLL_X, -1, -1, 0);
 
@@ -1235,12 +1235,13 @@ Bool wcmDevInit(WacomDevicePtr priv)
 {
 	WacomCommonPtr common =	priv->common;
 	int nbaxes, nbbuttons;
+	Bool use_smooth_panscrolling = priv->common->wcmPanscrollIsSmooth;
 
 	/* Detect tablet configuration, if possible */
 	if (priv->common->wcmModel->DetectConfig)
 		priv->common->wcmModel->DetectConfig (priv);
 
-	nbaxes = priv->naxes;       /* X, Y, Pressure, Tilt-X, Tilt-Y, Wheel, Scroll-X, Scroll-Y */
+	nbaxes = priv->naxes;       /* X, Y, Pressure, Tilt-X, Tilt-Y, Wheel */
 	if (!nbaxes || nbaxes > 6)
 		nbaxes = priv->naxes = 6;
 	nbbuttons = priv->nbuttons; /* Use actual number of buttons, if possible */
@@ -1248,7 +1249,8 @@ Bool wcmDevInit(WacomDevicePtr priv)
 	if (IsPad(priv) && TabletHasFeature(priv->common, WCM_DUALRING))
 		nbaxes = priv->naxes = nbaxes + 1; /* ABS wheel 2 */
 
-	if (IsPen(priv))
+	/* For smooth scrolling we set up two additional axes */
+	if (use_smooth_panscrolling && IsPen(priv))
 		nbaxes = priv->naxes = nbaxes + 2; /* Scroll X and Y */
 
 	/* if more than 3 buttons, offset by the four scroll buttons,
@@ -1286,7 +1288,7 @@ Bool wcmDevInit(WacomDevicePtr priv)
 		}
 	}
 
-	if (!wcmInitAxes(priv))
+	if (!wcmInitAxes(priv, use_smooth_panscrolling))
 		return FALSE;
 
 	return TRUE;
